@@ -373,9 +373,9 @@ class SerialHandler:
             logformat = self.__app.frm_settings.logformat
             if logformat in ("Bin", "All") and raw_data is not None:
                 self.__app.file_handler.write_logfile(raw_data)
-            if logformat in ("Hex", "All") and raw_data is not None:
+            if logformat in ("Hex", "Hex+Parsed", "All") and raw_data is not None:
                 self.__app.file_handler.write_logfile(raw_data.hex())
-            if logformat in ("Parsed", "All") and parsed_data is not None:
+            if logformat in ("Parsed", "Hex+Parsed", "All") and parsed_data is not None:
                 self.__app.file_handler.write_logfile(parsed_data)
 
     def flush(self):
